aboutsummaryrefslogtreecommitdiffstats
path: root/drivers/gpu
diff options
context:
space:
mode:
authorDave Airlie <airlied@redhat.com>2008-12-08 14:55:27 +1000
committerDave Airlie <airlied@linux.ie>2008-12-29 17:47:23 +1000
commitaa91c6665a5e387e488c4a0b5da2536cc9c9f16e (patch)
tree13f81c204cc627df0dcb43c09c8679e4416f12be /drivers/gpu
parentdrm/i915: Fix stolen memory detection on G45 and GM45. (diff)
downloadlinux-dev-aa91c6665a5e387e488c4a0b5da2536cc9c9f16e.tar.xz
linux-dev-aa91c6665a5e387e488c4a0b5da2536cc9c9f16e.zip
drm: pick an 800x600@60HZ mode by default for unknown CRT.
This is what X picks now, so we should do the same. Signed-off-by: Dave Airlie <airlied@redhat.com>
Diffstat (limited to 'drivers/gpu')
-rw-r--r--drivers/gpu/drm/drm_crtc_helper.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/drivers/gpu/drm/drm_crtc_helper.c b/drivers/gpu/drm/drm_crtc_helper.c
index 887ed33b0694..f914044ad971 100644
--- a/drivers/gpu/drm/drm_crtc_helper.c
+++ b/drivers/gpu/drm/drm_crtc_helper.c
@@ -34,12 +34,12 @@
#include "drm_crtc_helper.h"
/*
* Detailed mode info for a standard 640x480@60Hz monitor
*/
static struct drm_display_mode std_mode[] = {
- { DRM_MODE("640x480", DRM_MODE_TYPE_DEFAULT, 25200, 640, 656,
- 752, 800, 0, 480, 490, 492, 525, 0,
- DRM_MODE_FLAG_NHSYNC | DRM_MODE_FLAG_NVSYNC) },
+ { DRM_MODE("800x600", DRM_MODE_TYPE_DEFAULT, 40000, 800, 840,
+ 968, 1056, 0, 600, 601, 605, 628, 0,
+ DRM_MODE_FLAG_PHSYNC | DRM_MODE_FLAG_PVSYNC) },
};
/**
@@ -34,12 +34,12 @@
#include "drm_crtc_helper.h"
/*
- * Detailed mode info for a standard 640x480@60Hz monitor
+ * Detailed mode info for 800x600@60Hz
*/
static struct drm_display_mode std_mode[] = {